==> rpm-4.2.1-x86_64_slamd64-3.tgz: install/doinst.sh <==
if [ ! -r var/lib/rpm/Packages ]; then
  ( cd var/lib/rpm/tmp ; cp -a * .. )
fi
( cd var/lib/rpm && rm -f tmp/* && rmdir tmp )
# Symlinks:
( cd usr/bin ; rm -rf rpmu )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmu rpmu )
( cd usr/bin ; rm -rf rpmi )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmi rpmi )
( cd usr/bin ; rm -rf rpme )
( cd usr/bin ; ln -sf ../lib64/rpm/rpme rpme )
( cd usr/bin ; rm -rf rpmdb )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmd rpmdb )
( cd usr/bin ; rm -rf rpmsign )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmk rpmsign )
( cd usr/bin ; rm -rf rpmverify )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmv rpmverify )
( cd usr/bin ; rm -rf rpmquery )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmq rpmquery )
( cd usr/bin ; rm -rf rpmbuild )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmb rpmbuild )
( cd usr/lib64 ; rm -rf rpmpopt )
( cd usr/lib64 ; ln -sf rpm/rpmpopt rpmpopt )
( cd usr/lib64 ; rm -rf rpmrc )
( cd usr/lib64 ; ln -sf rpm/rpmrc rpmrc )
( cd usr/lib64 ; rm -rf librpmbuild.so )
( cd usr/lib64 ; ln -sf librpmbuild-4.2.so librpmbuild.so )
( cd usr/lib64 ; rm -rf librpm.so )
( cd usr/lib64 ; ln -sf librpm-4.2.so librpm.so )
( cd usr/lib64 ; rm -rf librpmdb.so )
( cd usr/lib64 ; ln -sf librpmdb-4.2.so librpmdb.so )
( cd usr/lib64 ; rm -rf librpmio.so )
( cd usr/lib64 ; ln -sf librpmio-4.2.so librpmio.so )
( cd usr/lib64/rpm ; rm -rf rpmpopt )
( cd usr/lib64/rpm ; ln -sf rpmpopt-4.2.1 rpmpopt )
( cd usr/lib64/rpm ; rm -rf rpmv )
( cd usr/lib64/rpm ; ln -sf rpmq rpmv )
( cd usr/lib64/rpm ; rm -rf rpmu )
( cd usr/lib64/rpm ; ln -sf rpmi rpmu )
( cd usr/lib64/rpm ; rm -rf rpme )
( cd usr/lib64/rpm ; ln -sf rpmi rpme )
( cd usr/lib64/rpm ; rm -rf rpmt )
( cd usr/lib64/rpm ; ln -sf rpmb rpmt )

==> rpm-4.4.2.3-x86_64_slamd64-2.tgz: install/doinst.sh <==
if [ ! -r var/lib/rpm/Packages ]; then
  ( cd var/lib/rpm/tmp ; cp -a * .. )
fi
( cd var/lib/rpm && rm -f tmp/* && rmdir tmp )
# Symlinks:
( cd usr/bin ; rm -rf rpme )
( cd usr/bin ; ln -sf ../lib64/rpm/rpme rpme )
( cd usr/bin ; rm -rf rpmi )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmi rpmi )
( cd usr/bin ; rm -rf rpmu )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmu rpmu )
( cd usr/bin ; rm -rf rpmdb )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmd rpmdb )
( cd usr/bin ; rm -rf rpmsign )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmk rpmsign )
( cd usr/bin ; rm -rf rpmverify )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmv rpmverify )
( cd usr/bin ; rm -rf rpmbuild )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmb rpmbuild )
( cd usr/bin ; rm -rf rpmquery )
( cd usr/bin ; ln -sf ../lib64/rpm/rpmq rpmquery )
( cd usr/lib64/rpm ; rm -rf rpme )
( cd usr/lib64/rpm ; ln -sf rpmi rpme )
( cd usr/lib64/rpm ; rm -rf rpmt )
( cd usr/lib64/rpm ; ln -sf rpmb rpmt )
( cd usr/lib64/rpm ; rm -rf rpmu )
( cd usr/lib64/rpm ; ln -sf rpmi rpmu )
( cd usr/lib64/rpm ; rm -rf rpmv )
( cd usr/lib64/rpm ; ln -sf rpmq rpmv )
( cd usr/lib64/rpm ; rm -rf rpmpopt )
( cd usr/lib64/rpm ; ln -sf rpmpopt-4.4.2.3 rpmpopt )
( cd usr/lib64 ; rm -rf librpm.so )
( cd usr/lib64 ; ln -sf librpm-4.4.so librpm.so )
( cd usr/lib64 ; rm -rf librpmdb.so )
( cd usr/lib64 ; ln -sf librpmdb-4.4.so librpmdb.so )
( cd usr/lib64 ; rm -rf librpmio.so )
( cd usr/lib64 ; ln -sf librpmio-4.4.so librpmio.so )
( cd usr/lib64 ; rm -rf librpmbuild.so )
( cd usr/lib64 ; ln -sf librpmbuild-4.4.so librpmbuild.so )
